#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-rerun
version:              1.1.20
visibility:           public
id:                   tasty-rerun-1.1.20-HwSN1uNFZAbJnWwOg7AfST
key:                  tasty-rerun-1.1.20-HwSN1uNFZAbJnWwOg7AfST
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  26578e2c8eb1802f1ec7e6581b3b3f95
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-rerun-1.1.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-rerun-1.1.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-rerun-1.1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-rerun
hs-libraries:         HStasty-rerun-1.1.20-HwSN1uNFZAbJnWwOg7AfST
depends:
    base-4.18.2.1 containers-0.6.7 filepath-1.4.300.1 mtl-2.3.1
    optparse-applicative-0.18.1.0-D1qnF9ppDr4DKTCW01gXle
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-FiRZ1IWcSZ79yf7Nf1HVSK transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

